#!/usr/bin/env python3
# Author: Dr. Konstantin Selyunin
# License: MIT
# Date: 3 May 2020

import logging
import sys

from pathlib import Path

from rsl_comm_py.shearwater_serial import ShearWaterSerial


if __name__ == '__main__':
    logging.basicConfig(
        level=logging.WARNING,
        format='[%(asctime)s.%(msecs)03d]: %(message)s',
        datefmt='%H:%M:%S',
        handlers=[
            logging.FileHandler(f'{Path(__file__).stem}.log', mode='w'),
            logging.StreamHandler(sys.stdout),
        ])
    script_dir = Path(__file__).parent
    # NOTE: specify path to YOUR device file below (see README how to create such file):
    device_file = script_dir.parent / "rsl_A500CNHD.json"
    shearwater = ShearWaterSerial(device=device_file)

    for packet in shearwater.recv_broadcast(num_packets=100):
        logging.warning(packet)




#!/usr/bin/env python3
# Author: Dr. Konstantin Selyunin
# License: MIT
# Date: 31 March 2020

import logging
import sys

from pathlib import Path

from rsl_comm_py.shearwater_serial import ShearWaterSerial


if __name__ == '__main__':
    logging.basicConfig(
        level=logging.WARNING,
        format='[%(asctime)s.%(msecs)03d] [%(levelname)-8s]:  %(message)s',
        datefmt='%Y-%m-%d %H:%M:%S',
        handlers=[
            logging.FileHandler(f'{Path(__file__).stem}.log'),
            logging.StreamHandler(sys.stdout),
        ])
    script_dir = Path(__file__).parent
    device_file = script_dir.parent / "rsl_A500CNHD.json"
    shearwater = ShearWaterSerial(device=device_file)

    print(f"\n========== INCLINATION ===================================")
    for _ in range(10):
        print(f"dreg_velocity_time            : {shearwater.dreg_velocity_time[1]}")




#!/usr/bin/env python

# Author: Dr. Konstantin Selyunin
# License: MIT

import argparse
import json
import sys

from argparse import RawTextHelpFormatter
from serial.tools import list_ports
from typing import Dict, Tuple


def autodetect(file_name=None) -> Tuple[bool, Dict]:
    json_config = {}
    device_list = list_ports.comports()
    for device in device_list:
        # go through device list and stop on first FTDI device
        if device.manufacturer == "FTDI":
            # found something, add keys
            # device.device is the port name (COM4 for example)
            json_config['ID_VENDOR'] = device.manufacturer
            json_config['ID_SERIAL_SHORT'] = device.serial_number
            # don't know what the model should look like so were making it "pid:vid"
            json_config['ID_MODEL'] = '{0:04x}:{1:04x}'.format(device.vid, device.pid)
            if file_name is None:
                file_name = f"rsl_{json_config['ID_SERIAL_SHORT']}.json"
            with open(file_name, 'w') as fp:
                json.dump(json_config, fp, indent=2)
            return True, json_config
    # none of the devices was FTDI
    return False, {}


def autodetect_windows(file_name=None):
    return autodetect(file_name)


def autodetect_linux(file_name=None):
    return autodetect(file_name)


def autodetect_mac(file_name=None):
    return autodetect(file_name)


def rsl_autodetect(file_name=None) -> Tuple[bool, Dict]:
    """
    :param file_name: by default ID of sensor will be assigned
    :return: id file will be created in target directory
    """
    if sys.platform.startswith('win32'):
        return autodetect_windows(file_name)
    elif sys.platform.startswith('linux'):
        return autodetect_linux(file_name)
    elif sys.platform.startswith('darwin'):
        return autodetect_mac(file_name)


description = \
"""
Store RSL-sensor USB2Serial parameters on a Linux, Windows, Mac.
If RSL Board is connected via the USB2Serial FTDI chip, 
and has no specific descriptor information to differentiate itself 
from other FTDI devices (e.g. stepper motors or other
devices implementing USB2Serial connection). 

In order to differentiate these devices, we 
have this script, which searches for available 
devices and stores information in a .json file.
\n
Follow the procedure below:
-------------------------------
\n
1. Disconnect all the USB2Serial-related devices;
2. Connect RSL sensor;
3. Launch the script (with additional -f flag, which specifies file name);
4. The file `rsl_[serial_id].json` containing device 
specific information appears on success.

This file will be used by UM7, UM8, shearwater drivers
"""

if __name__ == '__main__':
    parser = argparse.ArgumentParser(description=description, formatter_class=RawTextHelpFormatter)
    parser.add_argument('-f', '--file', type=str, help='')
    args = parser.parse_args(sys.argv[1:])
    ok, config = rsl_autodetect(args.file)
    print(config)
    if not ok:
        print("FAILED to store ID of the RSL-Board! Check whether the sensor is connected!")



#!/usr/bin/env python3
# Author: Dr. Konstantin Selyunin
# License: MIT
# Date: 19 August 2020

import logging
import sys
import json

from pathlib import Path

from rsl_comm_py.shearwater_serial import ShearWaterSerial


if __name__ == '__main__':
    logging.basicConfig(
        level=logging.WARNING,
        format='[%(asctime)s.%(msecs)03d] [%(levelname)-8s]:  %(message)s',
        datefmt='%Y-%m-%d %H:%M:%S',
        handlers=[
            logging.FileHandler(f'{Path(__file__).stem}.log'),
            logging.StreamHandler(sys.stdout),
        ])
    script_dir = Path(__file__).parent
    device_file = script_dir.parent / "rsl_A500CNHD.json"
    shearwater = ShearWaterSerial(device=device_file)
    hidden_register_values = []
    _, uid_1 = shearwater.board_unique_id_1
    for reg in shearwater.svd_parser.hidden_regs:
        name = reg.name.lower()
        reg, *_ = getattr(shearwater, name)
        hidden_register_values.append(reg.as_dict())

    creg_register_str = json.dumps(hidden_register_values, indent=2)
    json_file_name = f'shearwater_hidden_{uid_1:0X}.json'
    with open(json_file_name, 'w') as fd:
        fd.write(creg_register_str)

    logging.warning(f'OK: Configuration settings written to file: `{json_file_name}`')




#!/usr/bin/env python3
# Author: Dr. Konstantin Selyunin
# License: MIT
# Date: 27 November 2020
# Modified: 08 December 2021


import logging
import sys

from pathlib import Path

from rsl_comm_py.um7_serial import UM7Serial


if __name__ == '__main__':
    logging.basicConfig(
        level=logging.WARNING,
        format='[%(asctime)s.%(msecs)03d]: %(message)s',
        datefmt='%H:%M:%S',
        handlers=[
            logging.FileHandler(f'{Path(__file__).stem}.log', mode='w'),
            logging.StreamHandler(sys.stdout),
        ])
    script_dir = Path(__file__).parent
    device_file = script_dir.parent / "rsl_A500CNP8.json"
    um7 = UM7Serial(device=device_file)
    creg_com_rates5, *_ = um7.creg_com_rates5
    print("creg_com_rates5: {}".format(creg_com_rates5))
    creg_com_settings, *_ = um7.creg_com_settings
    print("um7 creg_com_settings: {}".format(creg_com_settings))

    print(f"setting new quat rate: 20 Hz")
    # look at the register description -->
    # https://docs.redshiftlabs.com.au/register_map_current.html#creg-com-rates5
    # we are going to set the quaternion transmission rate to 20 Hz
    creg_com_rates5.set_field_value(QUAT_RATE=20)
    # we have now set a raw register value, let us write it in the sensor
    print(creg_com_rates5)
    um7.creg_com_rates5 = creg_com_rates5.raw_value

    # setting quaternion fusion
    creg_misc_settings, *_ = um7.creg_misc_settings
    creg_misc_settings.set_field_value(Q=1)
    um7.creg_misc_settings = creg_misc_settings.raw_value

    from time import sleep
    print("Sleeping 5 s... Zz")
    sleep(5)

    for packet in um7.recv_quaternion_broadcast(num_packets=100):
        logging.warning(packet)


import os
import stat

from pathlib import Path
from shutil import copy


def serve_autodetect_script(target_dir='./'):
    """
    Copies RSL autodetect script in target directory
    :param target_dir: directory to copy autodetect script to
    :return: 0 -- execution successful
    """
    autodetect_script = 'rsl_autodetect.py'
    src_path = Path(__file__).parent
    target_dir = Path(target_dir)
    autodetect_script_abspath = src_path / autodetect_script
    copy(autodetect_script_abspath, target_dir)
    # make copied file executable
    copied_file = target_dir / autodetect_script
    st = os.stat(copied_file)
    os.chmod(copied_file, st.st_mode | stat.S_IEXEC)



#!/usr/bin/env python3
# Author: Dr. Konstantin Selyunin
# License: MIT
# Date: 31 May 2020
# Modified: 08 December 2021

import logging
import sys

from pathlib import Path

from rsl_comm_py.um7_serial import UM7Serial


if __name__ == '__main__':
    logging.basicConfig(
        level=logging.WARNING,
        format='[%(asctime)s.%(msecs)03d]: %(message)s',
        datefmt='%H:%M:%S',
        handlers=[
            logging.FileHandler(f'{Path(__file__).stem}.log', mode='w'),
            logging.StreamHandler(sys.stdout),
        ])
    um7 = UM7Serial(port_name='/dev/ttyUSB0')

    print("um7 firmware revision: {}".format(um7.get_fw_revision))
    # for packet in um7.recv_broadcast(num_packets=1000):
    #     logging.warning(packet)




#!/usr/bin/env python3
# Author: Dr. Konstantin Selyunin
# License: MIT
# Date: 29 May 2020
# Modified: 08 December 2021


import logging
import sys

from pathlib import Path

from rsl_comm_py.um7_serial import UM7Serial


if __name__ == '__main__':
    logging.basicConfig(
        level=logging.WARNING,
        format='[%(asctime)s.%(msecs)03d]: %(message)s',
        datefmt='%H:%M:%S',
        handlers=[
            logging.FileHandler(f'{Path(__file__).stem}.log', mode='w'),
            logging.StreamHandler(sys.stdout),
        ])
    script_dir = Path(__file__).parent
    device_file = script_dir.parent / "rsl_A500CNP8.json"
    um7 = UM7Serial(device=device_file)

    flush_on_start = True  # <-- optional, set to true if you want to reset input buffer when starting reception
    for packet in um7.recv_health_broadcast(num_packets=100, flush_buffer_on_start=flush_on_start):
        logging.warning(packet)

